SendSparseHandle

Struct SendSparseHandle 

pub struct SendSparseHandle(pub cusparseHandle_t);
Phase 4 cuSPARSE handle wrapper. Raw pointer is !Send by default; cuSPARSE is thread-safe per-handle as long as a given handle is only touched by one stream at a time (the actor-per-handle invariant).

Tuple Fields

0: cusparseHandle_t